==> quassel_0.3.0.orig.tar.gz: quassel-0.3.0/src/qtui/aboutdlg.h <==
/***************************************************************************
 *   Copyright (C) 2005-08 by the Quassel IRC Team                         *
 *   devel@quassel-irc.org                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) version 3.                                           *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef ABOUTDLG_H_
#define ABOUTDLG_H_

#include <QDialog>

#include "ui_aboutdlg.h"

class AboutDlg : public QDialog {
  Q_OBJECT

  public:
    AboutDlg(QWidget *parent = 0);

  private:
    Ui::AboutDlg ui;

    QString about() const;
    QString authors() const;
    QString contributors() const;
    QString thanksTo() const;

};


#endif

==> quassel_0.13.1.orig.tar.gz: quassel-0.13.1/src/qtui/aboutdlg.h <==
/***************************************************************************
 *   Copyright (C) 2005-2019 by the Quassel Project                        *
 *   devel@quassel-irc.org                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) version 3.                                           *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef ABOUTDLG_H_
#define ABOUTDLG_H_

#include <QDialog>

#include "ui_aboutdlg.h"

class AboutData;

class AboutDlg : public QDialog
{
    Q_OBJECT

public:
    AboutDlg(QWidget *parent = 0);

private:
    Ui::AboutDlg ui;

    QString about() const;
    QString authors() const;
    QString contributors() const;
    QString thanksTo() const;

    AboutData *_aboutData;
};


#endif
